==> spirit_hub-0.0.1.9.tar.gz: spirit_hub-0.0.1.9/e2e/cypress/e2e/features/views/todos.js <==
import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';

Given('There is one tagset todo with all columns', () => {
  cy.appFactories([['create', 'operation', { id: 'operation1', title: 'Operation 1' }]]);
  cy.appFactories([
    ['create', 'tagset_doc', 'with_informed', 'with_file', { responsible: '1', parent_tagset_ids: ['a'], percent: 20, operation_id: 'operation1', accounted: ['1'] }],
  ]);
});

Then('I should see the right columns', () => {
  cy.get('#model_table td').eq(3).contains('Doc Title 1');
  cy.get('#model_table td').eq(4).contains('Operation 1');
  cy.get('#model_table td').eq(5).contains('7.1 Ko');
  cy.get('#model_table td').eq(6).contains(new Date().toLocaleDateString('fr-FR'));
  cy.get('#model_table td').eq(7).find('div').should('exist');
  cy.get('#model_table td').eq(8).find('img').should('exist');
  cy.get('#model_table td').eq(9).contains('À classer');
  cy.get('#model_table td').eq(10).find('a').should('exist');
});

Given('There is some todos docs', () => {
  cy.appFactories([['create_list', 'tagset_doc', 5, { responsible: '1', parent_tagset_ids: ['a'], percent: 20, accounted: ['1'] }]]);
});

Given('There is a lot of todos docs', () => {
  cy.appFactories([['create_list', 'tagset_doc', 20, { responsible: '1', parent_tagset_ids: ['a'], percent: 20, accounted: ['1'] }]]);
});

Given('There is some todos docs and some directories', () => {
  cy.appFactories([['create_list', 'tagset_doc', 5, { responsible: '1', parent_tagset_ids: ['a'], percent: 20, accounted: ['1'] }]]);
  cy.appFactories([['create_list', 'tagset_directory', 10, { responsible: '1' }]]);
});

// Add doc
Then('I should not see the doc in the list', () => {
  cy.get('#model_table tbody tr:visible').should('have.length', 5);
});

Then('I should see the doc in the list', () => {
  cy.get('#model_table tbody tr:visible').should('have.length', 6);
});

When('I click on the last created doc', () => {
  cy.get('#model_table tbody tr:first td:last a:first').click();
});

Then('I should see the history logs', () => {
  cy.get('button#history-logs').click();
});

Given('There is a doc to validate on my todos page', () => {
  cy.appFactories([
    ['create', 'tagset_doc', 'with_state', { state_key: 'to_validate', accounted: ['1'], percent: 20, responsible: '1', parent_tagset_ids: ['a'], accounted: ['1'] }],
  ]);
});

==> spirit_hub-0.0.1.11.tar.gz: spirit_hub-0.0.1.11/e2e/cypress/e2e/features/views/todos.js <==
import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';

Given('There is one tagset todo with all columns', () => {
  cy.appFactories([['create', 'operation', { id: 'operation1', title: 'Operation 1' }]]);
  cy.appFactories([
    ['create', 'tagset_doc', 'with_informed', 'with_file', { responsible: '1', parent_tagset_ids: ['a'], percent: 20, operation_id: 'operation1', accounted: ['1'] }],
  ]);
});

Then('I should see the right columns', () => {
  cy.get('#model_table td').eq(3).contains('Doc Title 1');
  cy.get('#model_table td').eq(4).contains('Operation 1');
  cy.get('#model_table td').eq(5).contains('7.1 Ko');
  cy.get('#model_table td').eq(6).contains(new Date().toLocaleDateString('fr-FR'));
  cy.get('#model_table td').eq(7).find('div').should('exist');
  cy.get('#model_table td').eq(8).find('img').should('exist');
  cy.get('#model_table td').eq(9).contains('À classer');
  cy.get('#model_table td').eq(10).find('a').should('exist');
});

Given('There is some todos docs', () => {
  cy.appFactories([['create_list', 'tagset_doc', 5, { responsible: '1', parent_tagset_ids: ['a'], percent: 20, accounted: ['1'] }]]);
});

Given('There is a lot of todos docs', () => {
  cy.appFactories([['create_list', 'tagset_doc', 20, { responsible: '1', parent_tagset_ids: ['a'], percent: 20, accounted: ['1'] }]]);
});

Given('There is some todos docs and some directories', () => {
  cy.appFactories([['create_list', 'tagset_doc', 5, { responsible: '1', parent_tagset_ids: ['a'], percent: 20, accounted: ['1'] }]]);
  cy.appFactories([['create_list', 'tagset_directory', 10, { responsible: '1' }]]);
});

// Add doc
Then('I should not see the doc in the list', () => {
  cy.get('#model_table tbody tr:visible').should('have.length', 5);
});

Then('I should see the doc in the list', () => {
  cy.get('#model_table tbody tr:visible').should('have.length', 6);
});

When('I click on the last created doc', () => {
  cy.get('#model_table tbody tr:first td:last a:first').click();
});

Then('I should see the history journal entries', () => {
  cy.get('button#history-journal-entries').click();
});

Given('There is a doc to validate on my todos page', () => {
  cy.appFactories([
    ['create', 'tagset_doc', 'with_state', { state_key: 'to_validate', accounted: ['1'], percent: 20, responsible: '1', parent_tagset_ids: ['a'], accounted: ['1'] }],
  ]);
});

Then('I can see user selected by default', () => {
  cy.get('#model_table tbody tr:first form[action="/spirit_hub/tagsets/form/validate"] button').click();
  cy.get('select[name="recipients[]"]').contains('Admin User (admin@test.com)');
});

Then('I can validate the doc', () => {
  cy.get('textarea[name="message"]').type('This is a message');
  cy.get('button[data-base-form-target="submitButton"]').click({ force: true });
  cy.waitForTurboResponse();
  cy.get('#model_table tbody tr:first').contains('Validé');
});
